@@ -1,10 +1,10 @@
 # -*- Mode: Python -*-
 
-import sys
+import gc
 import unittest
+import sys
 
-import glib
-
+from common import gobject
 
 class TestProcess(unittest.TestCase):
 
@@ -14,11 +14,14 @@ class TestProcess(unittest.TestCase):
 
     def testChildWatch(self):
         self.data = None
-        self.loop = glib.MainLoop()
+        self.loop = gobject.MainLoop()
         argv = [sys.executable, '-c', 'import sys']
-        pid, stdin, stdout, stderr = glib.spawn_async(
-            argv, flags=glib.SPAWN_DO_NOT_REAP_CHILD)
+        pid, stdin, stdout, stderr = gobject.spawn_async(
+            argv, flags=gobject.SPAWN_DO_NOT_REAP_CHILD)
         pid.close()
-        glib.child_watch_add(pid, self._child_watch_cb, 12345)
+        gobject.child_watch_add(pid, self._child_watch_cb, 12345)
         self.loop.run()
         self.assertEqual(self.data, 12345)
+
+if __name__ == '__main__':
+    unittest.main()
